@@ -1,5 +1,5 @@
 ## File Name: immer_cmml.R
-## File Version: 0.29
+## File Version: 0.303
 
 
 immer_cmml <- function( suff_stat, cpml_design, control=NULL )
@@ -16,7 +16,8 @@ immer_cmml <- function( suff_stat, cpml_design, control=NULL )
     #**** attach arguments
     freq <- as.vector(suff_stat[,"freq"])
     item_table <- as.matrix(suff_stat[, c("item1","item2","cat1","cat2")])
-    item_pairs <- as.matrix(suff_stat[ (suff_stat$cat1==0) & (suff_stat$cat2==0), c("item1", "item2") ])
+    item_pairs <- as.matrix(suff_stat[ (suff_stat$cat1==0) & (suff_stat$cat2==0),
+                                c("item1", "item2") ])
 
     LAM_init <- cpml_design$LAM_init
     GAM_init <- cpml_design$GAM_init
@@ -46,8 +47,9 @@ immer_cmml <- function( suff_stat, cpml_design, control=NULL )
     W_PSI <- immer_cmml_proc_parameter_index( W_par=W_PSI, par_index=PSI_index )
 
     #**** create basis parameters
-    res <- immer_cmml_proc_basispar( LAM_basispar=LAM_basispar, GAM_basispar=GAM_basispar,
-                PHI_basispar=PHI_basispar, PSI_basispar=PSI_basispar, LAM_index=LAM_index,
+    res <- immer_cmml_proc_basispar( LAM_basispar=LAM_basispar,
+                GAM_basispar=GAM_basispar, PHI_basispar=PHI_basispar,
+                PSI_basispar=PSI_basispar, LAM_index=LAM_index,
                 GAM_index=GAM_index, PHI_index=PHI_index, PSI_index=PSI_index )
     basispar <- res$basispar
     basispar_design <- res$basispar_design
@@ -67,27 +69,32 @@ immer_cmml <- function( suff_stat, cpml_design, control=NULL )
 
     #- define optimization function
     opt_fct <- function(par){
-        res <- immer_cmml_basispar_to_probs( basispar=par, basispar_design=basispar_design1,
-                basispar_length=basispar_length, W_LAM=W_LAM, LAM_init=LAM_init, LAM_index=LAM_index1,
-                W_GAM=W_GAM, GAM_init=GAM_init, GAM_index=GAM_index1, W_PHI=W_PHI, PHI_init=PHI_init,
-                PHI_index=PHI_index1, W_PSI=W_PSI, PSI_init=PSI_init, PSI_index=PSI_index1,
-                N_LAM=N_LAM, N_GAM=N_GAM, N_PHI=N_PHI, N_PSI=N_PSI, item_pairs=item_pairs,
-                item_table=item_table, tau_index=tau_index1, rho_index=rho_index1, N_rho=N_rho,
-                N_tau=N_tau, do_log_LAM=do_log_LAM, do_log_GAM=do_log_GAM, do_log_PHI=do_log_PHI,
-                do_log_PSI=do_log_PSI )
+        res <- immer_cmml_basispar_to_probs( basispar=par,
+                    basispar_design=basispar_design1, basispar_length=basispar_length,
+                    W_LAM=W_LAM, LAM_init=LAM_init, LAM_index=LAM_index1,
+                    W_GAM=W_GAM, GAM_init=GAM_init, GAM_index=GAM_index1, W_PHI=W_PHI,
+                    PHI_init=PHI_init, PHI_index=PHI_index1, W_PSI=W_PSI,
+                    PSI_init=PSI_init, PSI_index=PSI_index1, N_LAM=N_LAM, N_GAM=N_GAM,
+                    N_PHI=N_PHI, N_PSI=N_PSI, item_pairs=item_pairs,
+                    item_table=item_table, tau_index=tau_index1, rho_index=rho_index1,
+                    N_rho=N_rho, N_tau=N_tau, do_log_LAM=do_log_LAM,
+                    do_log_GAM=do_log_GAM, do_log_PHI=do_log_PHI,
+                    do_log_PSI=do_log_PSI )
         probs <- res$probs + eps
         val <- - sum( freq * log( probs ) )
         return(val)
     }
 
-    res <- immer_cmml_basispar_to_derivatives( basispar=basispar, basispar_design=basispar_design1,
-        basispar_length=basispar_length, W_LAM=W_LAM, LAM_init=LAM_init, LAM_index=LAM_index1,
-        W_GAM=W_GAM, GAM_init=GAM_init, GAM_index=GAM_index1, W_PHI=W_PHI, PHI_init=PHI_init,
-        PHI_index=PHI_index1, W_PSI=W_PSI, PSI_init=PSI_init, PSI_index=PSI_index1,
-        N_LAM=N_LAM, N_GAM=N_GAM, N_PHI=N_PHI, N_PSI=N_PSI, item_pairs=item_pairs,
-        item_table=item_table, tau_index=tau_index1, rho_index=rho_index1, N_rho=N_rho,
-        N_tau=N_tau, do_log_LAM=do_log_LAM, do_log_GAM=do_log_GAM, do_log_PHI=do_log_PHI,
-        do_log_PSI=do_log_PSI )
+    res <- immer_cmml_basispar_to_derivatives( basispar=basispar,
+                basispar_design=basispar_design1, basispar_length=basispar_length,
+                W_LAM=W_LAM, LAM_init=LAM_init, LAM_index=LAM_index1,
+                W_GAM=W_GAM, GAM_init=GAM_init, GAM_index=GAM_index1, W_PHI=W_PHI,
+                PHI_init=PHI_init, PHI_index=PHI_index1, W_PSI=W_PSI,
+                PSI_init=PSI_init, PSI_index=PSI_index1, N_LAM=N_LAM, N_GAM=N_GAM,
+                N_PHI=N_PHI, N_PSI=N_PSI, item_pairs=item_pairs,
+                item_table=item_table, tau_index=tau_index1, rho_index=rho_index1,
+                N_rho=N_rho, N_tau=N_tau, do_log_LAM=do_log_LAM,
+                do_log_GAM=do_log_GAM, do_log_PHI=do_log_PHI, do_log_PSI=do_log_PSI )
 
 
     #**** rearrange objects for output
